==> xwxapt-2.4.tar.bz2: xwxapt-2.4/src/callbacks.h <==
#include <gtk/gtk.h>


void
on_main_window_destroy                 (GtkObject       *object,
                                        gpointer         user_data);

gboolean
on_main_window_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_viewport_button_press_event         (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_audio_lev_button_press_event        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_noaa_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_meteor_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_operation_timer_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_start_stop_timer_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cancel_timer_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_set_up_audio_level_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_decode_from_dsp_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_record_to_file_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_decode_from_file_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_normalize_images_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_colorize_images_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_invert_images_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stop_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_quit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_fileselection_response              (GtkDialog       *dialog,
                                        gint             response_id,
                                        gpointer         user_data);

void
on_timeout_okbutton_clicked            (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_error_dialog_delete_event           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_error_dialog_destroy                (GtkObject       *object,
                                        gpointer         user_data);

void
on_error_ok_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_error_quit_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_hrs_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_min_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_start_stop_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_start_stop_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_quit_cancel_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_quit_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

==> xwxapt-2.7.tar.bz2: xwxapt-2.7/src/callbacks.h <==
#include <gtk/gtk.h>


void
on_main_window_destroy                 (GtkObject       *object,
                                        gpointer         user_data);

gboolean
on_main_window_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_viewport_button_press_event         (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_receive_togglebutton_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_normalize_togglebutton_toggled      (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_colorize_togglebutton_toggled       (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_invert_togglebutton_toggled         (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_fft_drawingarea_configure_event     (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_fft_drawingarea_expose_event        (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_demod_drawingarea_configure_event   (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_demod_drawingarea_expose_event      (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

void
on_level_setup_togglebutton_toggled    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_bw_entry_activate                   (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_freq_entry_activate                 (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_dagc_checkbutton_toggled            (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_gain_hscale_value_changed           (GtkRange        *range,
                                        gpointer         user_data);

void
on_auto_checkbutton_toggled            (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_offset_checkbutton_toggled         (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_operation_timer_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_start_stop_timer_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cancel_timer_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_noaa18_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_noaa19_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_meteor_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_decode_from_dsp_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_record_to_file_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_decode_from_file_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stop_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_quit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_fileselection_response              (GtkDialog       *dialog,
                                        gint             response_id,
                                        gpointer         user_data);

void
on_timeout_okbutton_clicked            (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_error_dialog_delete_event           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_error_dialog_destroy                (GtkObject       *object,
                                        gpointer         user_data);

void
on_error_ok_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_error_quit_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_hrs_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_min_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_start_stop_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_start_stop_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_quit_cancel_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_quit_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_fft_drawingarea_size_allocate       (GtkWidget       *widget,
                                        GdkRectangle    *allocation,
                                        gpointer         user_data);

void
on_demod_drawingarea_size_allocate     (GtkWidget       *widget,
                                        GdkRectangle    *allocation,
                                        gpointer         user_data);

void
on_subcarrier_radiobutton_toggled      (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_carrier_radiobutton_toggled         (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_noaa15_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);
